/***************************************************************************/
/** @file     about.cpp
  * @brief    The About tab page (implementation).
  *
  * @b begin      : Wed Dec 29 1999<br>
  * @b copyright  : &copy; 1999-2001,2002 by Gordon Machel<br>
  * @b email      : gmachel@users.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  **************************************************************************/
#include <kapp.h>
#include <klocale.h>
#include <kiconloader.h>
#include <ktextbrowser.h>

#include <qlabel.h>
#include <qscrollview.h>
#include <qpushbutton.h>
#include <qframe.h>

#include "about.h"
#include "../config.h"

/*------------------------------------------------------------------------ */
About::About(QWidget *parent, const char *name) : QWidget(parent,name)
{
  QString buffer;

  this->resize(400,100);
  QLabel_1= new QLabel(this);
  QLabel_1->setGeometry(10,15,32,32);
  QLabel_1->setPixmap(DesktopIcon("ksetiwatch"));

  Help = new QPushButton(this);
  Help->setGeometry(48,18,75,25);
  Help->setText(i18n("Help"));
  connect(Help, SIGNAL(clicked()), SLOT(slotShowHelp()) );

  QLabel_2= new QLabel(this);
  QLabel_2->setGeometry(10,65,120,40);
  QLabel_2->setPixmap(DesktopIcon("MadeWithKDev"));

  AboutView = new KTextBrowser(this);
  AboutView->setGeometry(130,5,490,100);
  buffer =
    i18n("This is <a href=\"http://ksetiwatch.sf.net\">Ksetiwatch</a> %1, developed by "
         "<a href=\"mailto:gmachel@users.sf.net\">Gordon Machel</a> "
         "(gmachel@users.sf.net).").arg(VERSION) +
    i18n("<p>Ksetiwatch monitors multiple "
         "<a href=\"http://setiathome.ssl.berkeley.edu/index.html\">SETI@home</a> "
         "instances running on your computer or in your network. It "
         "shares the same look-and-feel of the popular "
         "<a href=\"http://members.shaw.ca/mloukko/SETI.html\">SETIWatch</a> "
         "tool for the Windows platforms, written by Mark Loukko.</p>") +
    i18n("<p>To make full use of this program, the latest version of the SETI@home "
         "client is required. Command-line clients for various platforms "
         "can be found <a href=\"http://setiathome.ssl.berkeley.edu/unix.html\">here</a>.</p>") +
    i18n("<p>Ksetiwatch is published under the GNU Public License (GPL), version 2.</p>") +
    i18n("<p>Special thanks to:") +
    i18n("<ul><li><b>John Aldrich, Renaud Michel, and Stephan Windischmann</b>,<br>"
         "for providing precompiled packages for various Linux distributions,</li>") +
    i18n("<li><b>Juan Manuel Garcia Molina and Luis Bolinches Martinez</b>,<br>"
         "for contributing the Spanish translation,</li>") +
    i18n("<li><b>Renaud Michel</b>,<br>"
         "for the French translation,</li>") +
    i18n("<li><b>Diego Iastrubni</b>,<br>"
         "for the Hebrew translation,</li>") +
    i18n("<li><b>Vladimir Vuksan</b>,<br>"
         "for the Croatian translation.</li></ul></p>") +
    i18n("<p>Many thanks for helpful hints, patches, and suggestions are given to: Frode Tennebo, "
         "Christian Sorensen, Kenny Lim, Hans Motsharg, Roeland Th. Jansen, Matthew Soffen, "
         "Peter Drumm, Stefan Pfeiffer, Hugues Talbot, Jan Knutar, Pelon, Dan Crooks, "
         "Xet Erixon, and Kjell Randa.</p>");
  AboutView->setText(buffer);
}

/*------------------------------------------------------------------------ */
About::~About()
{
}

/*------------------------------------------------------------------------ */
void About::resizeEvent(QResizeEvent*)
{
AboutView->resize(490, this->height()-10);
}

/*------------------------------------------------------------------------ */
void About::slotShowHelp()
{
kapp->invokeHelp();
}

#include "about.moc"

